@@ -59,11 +59,11 @@ class TestNode(BaseNode):
         "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
         "definition": {"module": ["vellum_custom_nodes", "test_node"], "name": "TestNode"},
         "display_data": {
-            "comment": {"value": "A test node for processing data."},
+            "comment": {"expanded": True, "value": "A test node for processing data."},
             "position": {"x": 0.0, "y": 0.0},
         },
         "id": "7a8b251d-f5ca-462a-b293-071d219460fb",
-        "label": "TestNode",
+        "label": "Test Node",
         "outputs": [],
         "ports": [{"id": "a3a0eefd-45d0-4f13-8c58-a836a9f7f9ed", "name": "default", "type": "DEFAULT"}],
         "trigger": {"id": "a022e36c-9852-4772-9be3-3c6c147fd811", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -122,9 +122,12 @@ class SomeOtherNode(BaseNode):
         "attributes": [],
         "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
         "definition": {"module": ["vellum_custom_nodes", "first_node"], "name": "SomeNode"},
-        "display_data": {"comment": {"value": "This is Some Node."}, "position": {"x": 0.0, "y": 0.0}},
+        "display_data": {
+            "comment": {"expanded": True, "value": "This is Some Node."},
+            "position": {"x": 0.0, "y": 0.0},
+        },
         "id": "1e559c2e-db82-41f0-9ceb-5e89b0c5a0a3",
-        "label": "SomeNode",
+        "label": "Some Node",
         "outputs": [],
         "ports": [{"id": "48e39e97-5fd4-471e-b4f2-51d3baf06456", "name": "default", "type": "DEFAULT"}],
         "trigger": {"id": "e3381fb7-61fc-4c46-ae8e-51fc463b6a59", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -142,9 +145,12 @@ class SomeOtherNode(BaseNode):
         "attributes": [],
         "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
         "definition": {"module": ["vellum_custom_nodes", "second_node"], "name": "SomeOtherNode"},
-        "display_data": {"comment": {"value": "This is Some Other Node."}, "position": {"x": 0.0, "y": 0.0}},
+        "display_data": {
+            "comment": {"expanded": True, "value": "This is Some Other Node."},
+            "position": {"x": 0.0, "y": 0.0},
+        },
         "id": "7aee541b-b245-4c8a-9137-3e4631d5100c",
-        "label": "SomeOtherNode",
+        "label": "Some Other Node",
         "outputs": [],
         "ports": [{"id": "fb66b46a-d970-4bc9-83ea-70c154c57ddd", "name": "default", "type": "DEFAULT"}],
         "trigger": {"id": "13fa2714-20b3-4bc3-ab79-621a188e3bfa", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -211,9 +217,12 @@ class HelperClass:
             "attributes": [],
             "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
             "definition": {"module": ["vellum_custom_nodes", "multiple_nodes"], "name": "ProcessingNode"},
-            "display_data": {"comment": {"value": "Processes input data."}, "position": {"x": 0.0, "y": 0.0}},
+            "display_data": {
+                "comment": {"expanded": True, "value": "Processes input data."},
+                "position": {"x": 0.0, "y": 0.0},
+            },
             "id": "f92c09f0-0434-46cb-829d-a73f801d6343",
-            "label": "ProcessingNode",
+            "label": "Processing Node",
             "outputs": [],
             "ports": [{"id": "abaa2984-b312-4491-b069-e689759f72c8", "name": "default", "type": "DEFAULT"}],
             "trigger": {"id": "35378c2b-f089-44af-ac37-efe4ea42c817", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -226,9 +235,12 @@ class HelperClass:
             "attributes": [],
             "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
             "definition": {"module": ["vellum_custom_nodes", "multiple_nodes"], "name": "TransformationNode"},
-            "display_data": {"comment": {"value": "Transforms data format."}, "position": {"x": 0.0, "y": 0.0}},
+            "display_data": {
+                "comment": {"expanded": True, "value": "Transforms data format."},
+                "position": {"x": 0.0, "y": 0.0},
+            },
             "id": "09ca32f7-c8f2-4469-97e5-1f288f85127a",
-            "label": "TransformationNode",
+            "label": "Transformation Node",
             "outputs": [],
             "ports": [{"id": "88778117-fbfc-4b44-964b-5a4994aa2f24", "name": "default", "type": "DEFAULT"}],
             "trigger": {"id": "5d096263-7fbf-490a-83b7-e441852b5fb6", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -289,9 +301,12 @@ class BrokenNode(BaseNode)
         "attributes": [],
         "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
         "definition": {"module": ["vellum_custom_nodes", "valid_node"], "name": "SomeNode"},
-        "display_data": {"comment": {"value": "This is Some Node."}, "position": {"x": 0.0, "y": 0.0}},
+        "display_data": {
+            "comment": {"expanded": True, "value": "This is Some Node."},
+            "position": {"x": 0.0, "y": 0.0},
+        },
         "id": "1e559c2e-db82-41f0-9ceb-5e89b0c5a0a3",
-        "label": "SomeNode",
+        "label": "Some Node",
         "outputs": [],
         "ports": [{"id": "48e39e97-5fd4-471e-b4f2-51d3baf06456", "name": "default", "type": "DEFAULT"}],
         "trigger": {"id": "e3381fb7-61fc-4c46-ae8e-51fc463b6a59", "merge_behavior": "AWAIT_ATTRIBUTES"},
@@ -368,11 +383,11 @@ class MyAdditionNode(BaseNode):
         "base": {"module": ["vellum", "workflows", "nodes", "bases", "base"], "name": "BaseNode"},
         "definition": {"module": ["vellum_custom_nodes", "addition_node"], "name": "MyAdditionNode"},
         "display_data": {
-            "comment": {"value": "Custom node that performs simple addition."},
+            "comment": {"expanded": True, "value": "Custom node that performs simple addition."},
             "position": {"x": 0.0, "y": 0.0},
         },
         "id": "195cd69d-3d2d-41e4-a432-16c433cb8d34",
-        "label": "MyAdditionNode",
+        "label": "My Addition Node",
         "outputs": [{"id": "3d8e40cb-2aa8-44bd-ae6a-708a9fbc4779", "name": "result", "type": "NUMBER", "value": None}],
         "ports": [{"id": "9a9e4ef6-febf-4093-a515-217bbb1373db", "name": "default", "type": "DEFAULT"}],
         "trigger": {"id": "a5298668-d808-4a45-a62e-790943948e8a", "merge_behavior": "AWAIT_ATTRIBUTES"},
