@@ -25,7 +25,6 @@ from vellum_ee.workflows.server.virtual_file_loader import VirtualFileFinder
 
 from vellum.workflows.exceptions import WorkflowInitializationException
 from vellum.workflows.nodes import BaseNode
-from vellum.workflows.utils.names import pascal_to_title_case
 from workflow_server.config import ENABLE_PROCESS_WRAPPER, MEMORY_LIMIT_MB
 from workflow_server.core.events import (
     SPAN_ID_EVENT,
@@ -493,7 +492,6 @@ def get_version_route() -> tuple[dict, int]:
                             exec_config_raw = node_display_class().serialize(WorkflowDisplayContext())
                             exec_config = cast(Dict[str, Any], exec_config_raw)
                             config_module = exec_config["definition"]["module"]
-                            label = exec_config["label"]
                             description = (
                                 exec_config["display_data"]["comment"]["value"]
                                 if "comment" in exec_config["display_data"]
@@ -504,7 +502,7 @@ def get_version_route() -> tuple[dict, int]:
                                     "id": str(uuid4()),
                                     "module": config_module,
                                     "name": obj.__name__,
-                                    "label": pascal_to_title_case(label),
+                                    "label": exec_config["label"],
                                     "description": description,
                                     "exec_config": exec_config,
                                 }
